#include <gio/gio.h>

#if defined (__ELF__) && ( __GNUC__ > 2 || (__GNUC__ == 2 && __GNUC_MINOR__ >= 6))
# define SECTION __attribute__ ((section (".gresource.launcher"), aligned (8)))
#else
# define SECTION
#endif

#ifdef _MSC_VER
static const SECTION union { const guint8 data[2412]; const double alignment; void * const ptr;}  launcher_resource_data = { {
  0107, 0126, 0141, 0162, 0151, 0141, 0156, 0164, 0000, 0000, 0000, 0000, 0000, 0000, 0000, 0000, 
  0030, 0000, 0000, 0000, 0034, 0001, 0000, 0000, 0000, 0000, 0000, 0050, 0011, 0000, 0000, 0000, 
  0000, 0000, 0000, 0000, 0001, 0000, 0000, 0000, 0002, 0000, 0000, 0000, 0003, 0000, 0000, 0000, 
  0003, 0000, 0000, 0000, 0003, 0000, 0000, 0000, 0006, 0000, 0000, 0000, 0010, 0000, 0000, 0000, 
  0010, 0000, 0000, 0000, 0002, 0111, 0155, 0161, 0007, 0000, 0000, 0000, 0034, 0001, 0000, 0000, 
  0027, 0000, 0166, 0000, 0070, 0001, 0000, 0000, 0213, 0007, 0000, 0000, 0113, 0120, 0220, 0013, 
  0003, 0000, 0000, 0000, 0213, 0007, 0000, 0000, 0004, 0000, 0114, 0000, 0220, 0007, 0000, 0000, 
  0224, 0007, 0000, 0000, 0260, 0267, 0044, 0060, 0001, 0000, 0000, 0000, 0224, 0007, 0000, 0000, 
  0006, 0000, 0114, 0000, 0234, 0007, 0000, 0000, 0240, 0007, 0000, 0000, 0324, 0265, 0002, 0000, 
  0377, 0377, 0377, 0377, 0240, 0007, 0000, 0000, 0001, 0000, 0114, 0000, 0244, 0007, 0000, 0000, 
  0250, 0007, 0000, 0000, 0272, 0272, 0177, 0171, 0006, 0000, 0000, 0000, 0250, 0007, 0000, 0000, 
  0010, 0000, 0114, 0000, 0260, 0007, 0000, 0000, 0264, 0007, 0000, 0000, 0173, 0263, 0273, 0305, 
  0007, 0000, 0000, 0000, 0264, 0007, 0000, 0000, 0020, 0000, 0166, 0000, 0310, 0007, 0000, 0000, 
  0164, 0010, 0000, 0000, 0322, 0005, 0350, 0052, 0002, 0000, 0000, 0000, 0164, 0010, 0000, 0000, 
  0014, 0000, 0114, 0000, 0200, 0010, 0000, 0000, 0204, 0010, 0000, 0000, 0333, 0070, 0037, 0025, 
  0004, 0000, 0000, 0000, 0204, 0010, 0000, 0000, 0011, 0000, 0114, 0000, 0220, 0010, 0000, 0000, 
  0234, 0010, 0000, 0000, 0243, 0263, 0074, 0225, 0007, 0000, 0000, 0000, 0234, 0010, 0000, 0000, 
  0027, 0000, 0166, 0000, 0270, 0010, 0000, 0000, 0153, 0011, 0000, 0000, 0147, 0160, 0055, 0151, 
  0143, 0157, 0156, 0055, 0156, 0141, 0155, 0145, 0055, 0143, 0150, 0157, 0157, 0163, 0145, 0162, 
  0056, 0165, 0151, 0000, 0000, 0000, 0000, 0000, 0333, 0067, 0000, 0000, 0001, 0000, 0000, 0000, 
  0170, 0332, 0355, 0133, 0113, 0217, 0333, 0066, 0020, 0276, 0347, 0127, 0250, 0272, 0026, 0216, 
  0327, 0116, 0020, 0004, 0205, 0355, 0000, 0131, 0064, 0151, 0200, 0264, 0050, 0272, 0333, 0366, 
  0050, 0320, 0322, 0254, 0305, 0056, 0115, 0252, 0044, 0275, 0266, 0363, 0353, 0073, 0024, 0375, 
  0222, 0105, 0331, 0022, 0245, 0175, 0064, 0360, 0315, 0222, 0311, 0341, 0360, 0233, 0367, 0170, 
  0074, 0372, 0260, 0232, 0263, 0340, 0001, 0244, 0242, 0202, 0217, 0303, 0301, 0353, 0253, 0060, 
  0000, 0036, 0213, 0204, 0362, 0331, 0070, 0374, 0363, 0366, 0123, 0357, 0175, 0370, 0141, 0362, 
  0152, 0364, 0103, 0257, 0027, 0174, 0006, 0016, 0222, 0150, 0110, 0202, 0045, 0325, 0151, 0060, 
  0143, 0044, 0201, 0340, 0315, 0353, 0341, 0360, 0365, 0060, 0350, 0365, 0160, 0021, 0345, 0032, 
  0344, 0035, 0211, 0141, 0362, 0052, 0010, 0106, 0022, 0376, 0135, 0120, 0011, 0052, 0140, 0164, 
  0072, 0016, 0147, 0372, 0376, 0307, 0160, 0177, 0020, 0156, 0273, 0012, 0373, 0371, 0072, 0061, 
  0375, 0007, 0142, 0035, 0304, 0214, 0050, 0065, 0016, 0077, 0353, 0373, 0257, 0124, 0351, 0033, 
  0055, 0044, 0204, 0001, 0115, 0306, 0041, 0215, 0005, 0217, 0124, 0376, 0154, 0326, 0343, 0216, 
  0130, 0260, 0305, 0234, 0053, 0373, 0204, 0317, 0206, 0071, 0373, 0256, 0307, 0311, 0034, 0360, 
  0063, 0062, 0262, 0322, 0071, 0123, 0233, 0045, 0366, 0353, 0100, 0257, 0063, 0100, 0136, 0342, 
  0224, 0110, 0042, 0045, 0131, 0133, 0026, 0234, 0104, 0314, 0261, 0366, 0123, 0053, 0062, 0112, 
  0023, 0236, 0020, 0231, 0124, 0123, 0231, 0012, 0301, 0200, 0360, 0055, 0215, 0121, 0377, 0340, 
  0172, 0243, 0276, 0105, 0307, 0015, 0324, 0255, 0004, 0370, 0125, 0044, 0300, 0076, 0121, 0206, 
  0310, 0037, 0300, 0165, 0147, 0137, 0154, 0050, 0146, 0122, 0144, 0040, 0365, 0072, 0060, 0034, 
  0215, 0303, 0070, 0245, 0054, 0211, 0346, 0146, 0143, 0070, 0331, 0243, 0073, 0352, 0157, 0327, 
  0225, 0116, 0326, 0060, 0317, 0030, 0112, 0176, 0167, 0166, 0366, 0005, 0267, 0375, 0206, 0324, 
  0256, 0123, 0041, 0224, 0071, 0072, 0043, 0022, 0270, 0316, 0331, 0372, 0233, 0362, 0104, 0054, 
  0253, 0016, 0047, 0310, 0235, 0210, 0027, 0052, 0234, 0174, 0042, 0114, 0035, 0235, 0132, 0136, 
  0237, 0300, 0035, 0131, 0060, 0035, 0055, 0151, 0242, 0323, 0160, 0362, 0356, 0352, 0252, 0356, 
  0216, 0024, 0350, 0054, 0325, 0341, 0344, 0355, 0371, 0055, 0106, 0022, 0121, 0212, 0352, 0033, 
  0116, 0022, 0112, 0230, 0230, 0225, 0066, 0344, 0230, 0155, 0044, 0246, 0251, 0146, 0060, 0045, 
  0133, 0170, 0135, 0222, 0371, 0005, 0320, 0066, 0344, 0107, 0262, 0221, 0111, 0232, 0077, 0106, 
  0207, 0173, 0312, 0114, 0074, 0120, 0105, 0247, 0014, 0225, 0374, 0126, 0056, 0112, 0260, 0370, 
  0100, 0351, 0274, 0251, 0341, 0075, 0014, 0264, 0044, 0134, 0241, 0104, 0011, 0036, 0070, 0016, 
  0327, 0200, 0044, 0156, 0200, 0231, 0073, 0030, 0301, 0006, 0106, 0262, 0116, 0152, 0071, 0014, 
  0373, 0147, 0327, 0325, 0077, 0056, 0264, 0026, 0334, 0336, 0033, 0071, 0214, 0201, 0105, 0123, 
  0373, 0352, 0160, 0137, 0231, 0063, 0106, 0246, 0250, 0217, 0056, 0316, 0256, 0163, 0052, 0056, 
  0176, 0274, 0140, 0074, 0003, 0145, 0223, 0155, 0022, 0142, 0240, 0017, 0240, 0242, 0215, 0316, 
  0235, 0331, 0255, 0350, 0214, 0023, 0266, 0075, 0222, 0321, 0370, 0036, 0222, 0060, 0110, 0321, 
  0101, 0060, 0220, 0107, 0150, 0105, 0233, 0357, 0243, 0170, 0032, 0006, 0026, 0144, 0247, 0335, 
  0251, 0045, 0311, 0062, 0100, 0254, 0271, 0330, 0173, 0041, 0353, 0107, 0366, 0006, 0274, 0175, 
  0163, 0044, 0276, 0246, 0342, 0124, 0271, 0212, 0264, 0025, 0247, 0125, 0264, 0107, 0025, 0247, 
  0002, 0256, 0250, 0106, 0311, 0234, 0260, 0214, 0027, 0253, 0006, 0005, 0224, 0133, 0253, 0201, 
  0071, 0117, 0257, 0031, 0024, 0337, 0031, 0331, 0033, 0021, 0157, 0361, 0132, 0314, 0146, 0240, 
  0060, 0262, 0367, 0110, 0254, 0061, 0076, 0227, 0110, 0364, 0113, 0064, 0312, 0352, 0145, 0160, 
  0041, 0361, 0075, 0046, 0016, 0247, 0321, 0062, 0213, 0042, 0343, 0111, 0303, 0011, 0360, 0244, 
  0056, 0306, 0231, 0060, 0022, 0065, 0152, 0067, 0160, 0157, 0301, 0267, 0307, 0247, 0173, 0051, 
  0374, 0255, 0230, 0315, 0030, 0024, 0325, 0236, 0310, 0070, 0255, 0247, 0366, 0057, 0330, 0373, 
  0224, 0356, 0356, 0276, 0377, 0227, 0071, 0231, 0101, 0170, 0274, 0316, 0363, 0246, 0276, 0141, 
  0253, 0152, 0157, 0236, 0255, 0230, 0217, 0250, 0073, 0011, 0325, 0275, 0073, 0114, 0065, 0172, 
  0152, 0075, 0237, 0012, 0064, 0223, 0152, 0102, 0056, 0145, 0165, 0250, 0307, 0163, 0152, 0365, 
  0320, 0127, 0253, 0213, 0054, 0027, 0276, 0054, 0212, 0334, 0341, 0333, 0305, 0352, 0271, 0363, 
  0021, 0041, 0051, 0246, 0215, 0304, 0142, 0200, 0325, 0201, 0246, 0061, 0141, 0276, 0251, 0307, 
  0115, 0156, 0250, 0273, 0254, 0153, 0153, 0267, 0205, 0254, 0353, 0061, 0214, 0366, 0164, 0214, 
  0251, 0151, 0167, 0226, 0371, 0237, 0271, 0226, 0353, 0002, 0373, 0220, 0277, 0071, 0157, 0032, 
  0171, 0202, 0034, 0231, 0242, 0013, 0075, 0271, 0063, 0353, 0175, 0154, 0153, 0156, 0272, 0065, 
  0223, 0164, 0116, 0344, 0072, 0362, 0064, 0352, 0063, 0004, 0115, 0044, 0173, 0260, 0211, 0207, 
  0207, 0243, 0051, 0220, 0252, 0233, 0116, 0224, 0243, 0273, 0225, 0141, 0017, 0013, 0105, 0076, 
  0073, 0012, 0362, 0173, 0341, 0106, 0233, 0207, 0315, 0252, 0026, 0241, 0376, 0111, 0074, 0035, 
  0254, 0062, 0274, 0105, 0303, 0314, 0012, 0013, 0122, 0326, 0314, 0276, 0366, 0256, 0361, 0352, 
  0161, 0003, 0176, 0321, 0013, 0076, 0275, 0177, 0070, 0332, 0207, 0152, 0067, 0243, 0074, 0142, 
  0160, 0207, 0126, 0074, 0030, 0066, 0334, 0046, 0155, 0315, 0333, 0170, 0237, 0026, 0231, 0307, 
  0256, 0251, 0300, 0224, 0150, 0336, 0144, 0143, 0155, 0177, 0357, 0114, 0353, 0121, 0340, 0050, 
  0357, 0160, 0362, 0256, 0255, 0263, 0055, 0313, 0374, 0305, 0244, 0070, 0347, 0057, 0131, 0175, 
  0321, 0046, 0227, 0155, 0165, 0341, 0266, 0227, 0156, 0255, 0032, 0355, 0320, 0073, 0215, 0240, 
  0033, 0305, 0257, 0171, 0101, 0133, 0265, 0276, 0045, 0226, 0135, 0340, 0331, 0260, 0251, 0142, 
  0173, 0244, 0352, 0047, 0037, 0262, 0053, 0302, 0060, 0312, 0125, 0172, 0346, 0363, 0001, 0351, 
  0134, 0314, 0151, 0035, 0177, 0332, 0305, 0242, 0126, 0161, 0251, 0170, 0373, 0223, 0327, 0163, 
  0304, 0145, 0177, 0005, 0275, 0211, 0245, 0140, 0014, 0222, 0102, 0373, 0365, 0251, 0065, 0325, 
  0227, 0104, 0252, 0162, 0356, 0061, 0127, 0217, 0062, 0223, 0366, 0141, 0306, 0313, 0001, 0235, 
  0200, 0017, 0055, 0225, 0022, 0004, 0140, 0123, 0214, 0121, 0136, 0213, 0304, 0111, 0254, 0335, 
  0170, 0377, 0105, 0141, 0231, 0011, 0251, 0303, 0123, 0333, 0072, 0100, 0273, 0053, 0337, 0120, 
  0357, 0236, 0025, 0316, 0217, 0052, 0155, 0302, 0210, 0355, 0352, 0132, 0327, 0021, 0061, 0252, 
  0316, 0135, 0276, 0106, 0241, 0062, 0170, 0163, 0125, 0227, 0373, 0316, 0340, 0354, 0022, 0122, 
  0027, 0255, 0115, 0355, 0001, 0221, 0051, 0036, 0320, 0372, 0031, 0330, 0076, 0236, 0017, 0351, 
  0102, 0075, 0041, 0305, 0262, 0147, 0373, 0203, 0305, 0316, 0361, 0201, 0104, 0042, 0134, 0023, 
  0155, 0327, 0264, 0252, 0045, 0232, 0272, 0362, 0032, 0076, 0255, 0056, 0241, 0263, 0104, 0334, 
  0115, 0315, 0312, 0006, 0347, 0003, 0332, 0352, 0251, 0013, 0072, 0032, 0234, 0117, 0023, 0304, 
  0174, 0375, 0145, 0127, 0061, 0154, 0360, 0230, 0061, 0354, 0024, 0154, 0247, 0041, 0153, 0025, 
  0363, 0375, 0261, 0362, 0216, 0365, 0047, 0060, 0252, 0304, 0247, 0111, 0012, 0177, 0003, 0031, 
  0221, 0104, 0013, 0371, 0235, 0046, 0362, 0337, 0221, 0246, 0014, 0236, 0127, 0123, 0056, 0305, 
  0336, 0245, 0330, 0053, 0025, 0173, 0273, 0037, 0365, 0057, 0345, 0336, 0245, 0334, 0273, 0224, 
  0173, 0136, 0345, 0236, 0261, 0041, 0123, 0362, 0035, 0114, 0131, 0345, 0131, 0345, 0363, 0126, 
  0177, 0155, 0310, 0330, 0046, 0156, 0015, 0357, 0131, 0111, 0340, 0140, 0204, 0314, 0116, 0234, 
  0171, 0337, 0310, 0216, 0274, 0205, 0223, 0267, 0276, 0024, 0250, 0206, 0371, 0166, 0110, 0154, 
  0060, 0174, 0137, 0233, 0114, 0241, 0274, 0062, 0104, 0172, 0333, 0342, 0355, 0260, 0300, 0332, 
  0211, 0073, 0312, 0317, 0331, 0055, 0351, 0260, 0276, 0072, 0376, 0341, 0310, 0024, 0160, 0350, 
  0167, 0034, 0277, 0035, 0355, 0231, 0331, 0255, 0352, 0344, 0267, 0243, 0156, 0132, 0005, 0327, 
  0300, 0330, 0037, 0300, 0023, 0220, 0040, 0177, 0247, 0253, 0351, 0342, 0316, 0132, 0114, 0226, 
  0177, 0216, 0142, 0140, 0314, 0243, 0151, 0200, 0101, 0040, 0151, 0240, 0251, 0056, 0022, 0353, 
  0366, 0044, 0224, 0026, 0361, 0075, 0126, 0364, 0337, 0240, 0021, 0241, 0172, 0205, 0063, 0256, 
  0043, 0132, 0113, 0072, 0135, 0150, 0120, 0065, 0170, 0333, 0055, 0076, 0230, 0215, 0350, 0331, 
  0237, 0121, 0061, 0007, 0335, 0175, 0173, 0236, 0271, 0272, 0247, 0326, 0250, 0354, 0273, 0121, 
  0233, 0133, 0130, 0151, 0253, 0064, 0346, 0072, 0377, 0157, 0225, 0131, 0327, 0317, 0235, 0116, 
  0364, 0223, 0014, 0215, 0071, 0230, 0371, 0324, 0030, 0170, 0003, 0077, 0353, 0354, 0277, 0111, 
  0222, 0345, 0323, 0277, 0341, 0144, 0051, 0144, 0142, 0034, 0114, 0173, 0172, 0073, 0317, 0373, 
  0322, 0254, 0302, 0364, 0305, 0236, 0321, 0040, 0056, 0255, 0256, 0113, 0253, 0313, 0257, 0201, 
  0341, 0123, 0225, 0167, 0321, 0277, 0030, 0166, 0335, 0277, 0250, 0202, 0246, 0032, 0026, 0137, 
  0110, 0374, 0340, 0360, 0252, 0370, 0052, 0140, 0160, 0102, 0120, 0167, 0050, 0341, 0072, 0205, 
  0270, 0070, 0157, 0275, 0371, 0357, 0210, 0173, 0364, 0264, 0341, 0324, 0165, 0052, 0226, 0373, 
  0077, 0243, 0230, 0134, 0101, 0005, 0202, 0263, 0365, 0113, 0037, 0022, 0053, 0017, 0271, 0066, 
  0236, 0250, 0310, 0263, 0165, 0017, 0256, 0023, 0111, 0060, 0337, 0347, 0011, 0215, 0155, 0347, 
  0365, 0354, 0376, 0102, 0006, 0257, 0363, 0071, 0342, 0302, 0314, 0327, 0126, 0234, 0261, 0021, 
  0364, 0166, 0300, 0173, 0263, 0356, 0021, 0246, 0276, 0174, 0114, 0254, 0061, 0270, 0155, 0155, 
  0154, 0330, 0205, 0215, 0265, 0037, 0146, 0153, 0062, 0331, 0325, 0146, 0226, 0155, 0320, 0371, 
  0230, 0357, 0250, 0277, 0375, 0167, 0326, 0344, 0325, 0250, 0177, 0360, 0027, 0274, 0377, 0000, 
  0115, 0052, 0125, 0170, 0000, 0050, 0165, 0165, 0141, 0171, 0051, 0157, 0162, 0147, 0057, 0000, 
  0002, 0000, 0000, 0000, 0147, 0156, 0157, 0155, 0145, 0057, 0000, 0000, 0006, 0000, 0000, 0000, 
  0057, 0000, 0000, 0000, 0001, 0000, 0000, 0000, 0155, 0157, 0144, 0165, 0154, 0145, 0163, 0057, 
  0007, 0000, 0000, 0000, 0154, 0141, 0165, 0156, 0143, 0150, 0145, 0162, 0055, 0155, 0145, 0156, 
  0165, 0056, 0165, 0151, 0000, 0000, 0000, 0000, 0242, 0001, 0000, 0000, 0001, 0000, 0000, 0000, 
  0170, 0332, 0245, 0221, 0061, 0016, 0302, 0060, 0014, 0105, 0367, 0236, 0042, 0312, 0016, 0271, 
  0100, 0310, 0011, 0030, 0270, 0001, 0162, 0132, 0043, 0054, 0045, 0151, 0345, 0070, 0003, 0267, 
  0047, 0051, 0052, 0144, 0241, 0003, 0214, 0337, 0366, 0377, 0176, 0262, 0055, 0045, 0101, 0276, 
  0301, 0210, 0156, 0120, 0312, 0106, 0114, 0105, 0321, 0164, 0322, 0001, 0112, 0032, 0357, 0310, 
  0207, 0126, 0321, 0255, 0127, 0273, 0031, 0107, 0241, 0071, 0275, 0124, 0325, 0044, 0030, 0067, 
  0121, 0045, 0210, 0060, 0371, 0042, 0250, 0022, 0104, 0154, 0031, 0036, 0203, 0126, 0302, 0220, 
  0162, 0000, 0001, 0037, 0152, 0361, 0201, 0131, 0273, 0353, 0171, 0215, 0267, 0346, 0155, 0331, 
  0211, 0201, 0165, 0251, 0166, 0033, 0322, 0061, 0174, 0063, 0133, 0323, 0023, 0375, 0201, 0167, 
  0341, 0171, 0101, 0026, 0302, 0374, 0043, 0342, 0262, 0027, 0320, 0143, 0132, 0323, 0035, 0325, 
  0232, 0166, 0155, 0067, 0324, 0201, 0317, 0127, 0236, 0127, 0071, 0204, 0354, 0000, 0050, 0165, 
  0165, 0141, 0171, 0051, 0147, 0156, 0157, 0155, 0145, 0055, 0160, 0141, 0156, 0145, 0154, 0057, 
  0004, 0000, 0000, 0000, 0154, 0141, 0165, 0156, 0143, 0150, 0145, 0162, 0057, 0000, 0000, 0000, 
  0010, 0000, 0000, 0000, 0000, 0000, 0000, 0000, 0005, 0000, 0000, 0000, 0143, 0165, 0163, 0164, 
  0157, 0155, 0055, 0154, 0141, 0165, 0156, 0143, 0150, 0145, 0162, 0055, 0155, 0145, 0156, 0165, 
  0056, 0165, 0151, 0000, 0000, 0000, 0000, 0000, 0267, 0001, 0000, 0000, 0001, 0000, 0000, 0000, 
  0170, 0332, 0245, 0221, 0075, 0016, 0302, 0060, 0014, 0205, 0367, 0236, 0042, 0362, 0136, 0162, 
  0201, 0064, 0047, 0140, 0340, 0006, 0310, 0115, 0215, 0210, 0224, 0237, 0052, 0161, 0006, 0156, 
  0117, 0122, 0004, 0104, 0110, 0164, 0351, 0370, 0354, 0347, 0347, 0117, 0266, 0262, 0201, 0051, 
  0335, 0320, 0220, 0036, 0204, 0120, 0236, 0102, 0021, 0166, 0231, 0300, 0224, 0314, 0321, 0217, 
  0016, 0113, 0060, 0167, 0112, 0143, 0153, 0100, 0263, 0124, 0123, 0046, 0303, 0066, 0206, 0227, 
  0252, 0332, 0062, 0371, 0267, 0250, 0022, 0231, 0223, 0235, 0013, 0223, 0010, 0350, 0151, 0002, 
  0207, 0063, 0071, 0020, 0234, 0060, 0144, 0207, 0214, 0263, 0253, 0305, 0007, 0145, 0320, 0327, 
  0363, 0026, 0257, 0344, 0147, 0144, 0047, 0006, 0267, 0245, 0240, 0177, 0310, 0116, 0356, 0137, 
  0206, 0222, 0075, 0330, 0001, 0312, 0113, 0212, 0053, 0045, 0266, 0224, 0217, 0221, 0256, 0173, 
  0071, 0075, 0255, 0222, 0335, 0211, 0225, 0154, 0267, 0327, 0103, 0065, 0174, 0137, 0365, 0004, 
  0056, 0116, 0215, 0104, 0000, 0050, 0165, 0165, 0141, 0171, 0051
} };
#else /* _MSC_VER */
static const SECTION union { const guint8 data[2412]; const double alignment; void * const ptr;}  launcher_resource_data = {
  "\107\126\141\162\151\141\156\164\000\000\000\000\000\000\000\000"
  "\030\000\000\000\034\001\000\000\000\000\000\050\011\000\000\000"
  "\000\000\000\000\001\000\000\000\002\000\000\000\003\000\000\000"
  "\003\000\000\000\003\000\000\000\006\000\000\000\010\000\000\000"
  "\010\000\000\000\002\111\155\161\007\000\000\000\034\001\000\000"
  "\027\000\166\000\070\001\000\000\213\007\000\000\113\120\220\013"
  "\003\000\000\000\213\007\000\000\004\000\114\000\220\007\000\000"
  "\224\007\000\000\260\267\044\060\001\000\000\000\224\007\000\000"
  "\006\000\114\000\234\007\000\000\240\007\000\000\324\265\002\000"
  "\377\377\377\377\240\007\000\000\001\000\114\000\244\007\000\000"
  "\250\007\000\000\272\272\177\171\006\000\000\000\250\007\000\000"
  "\010\000\114\000\260\007\000\000\264\007\000\000\173\263\273\305"
  "\007\000\000\000\264\007\000\000\020\000\166\000\310\007\000\000"
  "\164\010\000\000\322\005\350\052\002\000\000\000\164\010\000\000"
  "\014\000\114\000\200\010\000\000\204\010\000\000\333\070\037\025"
  "\004\000\000\000\204\010\000\000\011\000\114\000\220\010\000\000"
  "\234\010\000\000\243\263\074\225\007\000\000\000\234\010\000\000"
  "\027\000\166\000\270\010\000\000\153\011\000\000\147\160\055\151"
  "\143\157\156\055\156\141\155\145\055\143\150\157\157\163\145\162"
  "\056\165\151\000\000\000\000\000\333\067\000\000\001\000\000\000"
  "\170\332\355\133\113\217\333\066\020\276\347\127\250\272\026\216"
  "\327\116\020\004\205\355\000\131\064\151\200\264\050\272\333\366"
  "\050\320\322\254\305\056\115\252\044\275\266\363\353\073\024\375"
  "\222\105\331\022\245\175\064\360\315\222\311\341\360\233\367\170"
  "\074\372\260\232\263\340\001\244\242\202\217\303\301\353\253\060"
  "\000\036\213\204\362\331\070\374\363\366\123\357\175\370\141\362"
  "\152\364\103\257\027\174\006\016\222\150\110\202\045\325\151\060"
  "\143\044\201\340\315\353\341\360\365\060\350\365\160\021\345\032"
  "\344\035\211\141\362\052\010\106\022\376\135\120\011\052\140\164"
  "\072\016\147\372\376\307\160\177\020\156\273\012\373\371\072\061"
  "\375\007\142\035\304\214\050\065\016\077\353\373\257\124\351\033"
  "\055\044\204\001\115\306\041\215\005\217\124\376\154\326\343\216"
  "\130\260\305\234\053\373\204\317\206\071\373\256\307\311\034\360"
  "\063\062\262\322\071\123\233\045\366\353\100\257\063\100\136\342"
  "\224\110\042\045\131\133\026\234\104\314\261\366\123\053\062\112"
  "\023\236\020\231\124\123\231\012\301\200\360\055\215\121\377\340"
  "\172\243\276\105\307\015\324\255\004\370\125\044\300\076\121\206"
  "\310\037\300\165\147\137\154\050\146\122\144\040\365\072\060\034"
  "\215\303\070\245\054\211\346\146\143\070\331\243\073\352\157\327"
  "\225\116\326\060\317\030\112\176\167\166\366\005\267\375\206\324"
  "\256\123\041\224\071\072\043\022\270\316\331\372\233\362\104\054"
  "\253\016\047\310\235\210\027\052\234\174\042\114\035\235\132\136"
  "\237\300\035\131\060\035\055\151\242\323\160\362\356\352\252\356"
  "\216\024\350\054\325\341\344\355\371\055\106\022\121\212\352\033"
  "\116\022\112\230\230\225\066\344\230\155\044\246\251\146\060\045"
  "\133\170\135\222\371\005\320\066\344\107\262\221\111\232\077\106"
  "\207\173\312\114\074\120\105\247\014\225\374\126\056\112\260\370"
  "\100\351\274\251\341\075\014\264\044\134\241\104\011\036\070\016"
  "\327\200\044\156\200\231\073\030\301\006\106\262\116\152\071\014"
  "\373\147\327\325\077\056\264\026\334\336\033\071\214\201\105\123"
  "\373\352\160\137\231\063\106\246\250\217\056\316\256\163\052\056"
  "\176\274\140\074\003\145\223\155\022\142\240\017\240\242\215\316"
  "\235\331\255\350\214\023\266\075\222\321\370\036\222\060\110\321"
  "\101\060\220\107\150\105\233\357\243\170\032\006\026\144\247\335"
  "\251\045\311\062\100\254\271\330\173\041\353\107\366\006\274\175"
  "\163\044\276\246\342\124\271\212\264\025\247\125\264\107\025\247"
  "\002\256\250\106\311\234\260\214\027\253\006\005\224\133\253\201"
  "\071\117\257\031\024\337\031\331\033\021\157\361\132\314\146\240"
  "\060\262\367\110\254\061\076\227\110\364\113\064\312\352\145\160"
  "\041\361\075\046\016\247\321\062\213\042\343\111\303\011\360\244"
  "\056\306\231\060\022\065\152\067\160\157\301\267\307\247\173\051"
  "\374\255\230\315\030\024\325\236\310\070\255\247\366\057\330\373"
  "\224\356\356\276\377\227\071\231\101\170\274\316\363\246\276\141"
  "\253\152\157\236\255\230\217\250\073\011\325\275\073\114\065\172"
  "\152\075\237\012\064\223\152\102\056\145\165\250\307\163\152\365"
  "\320\127\253\213\054\027\276\054\212\334\341\333\305\352\271\363"
  "\021\041\051\246\215\304\142\200\325\201\246\061\141\276\251\307"
  "\115\156\250\273\254\153\153\267\205\254\353\061\214\366\164\214"
  "\251\151\167\226\371\237\271\226\353\002\373\220\277\071\157\032"
  "\171\202\034\231\242\013\075\271\063\353\175\154\153\156\272\065"
  "\223\164\116\344\072\362\064\352\063\004\115\044\173\260\211\207"
  "\207\243\051\220\252\233\116\224\243\273\225\141\017\013\105\076"
  "\073\012\362\173\341\106\233\207\315\252\026\241\376\111\074\035"
  "\254\062\274\105\303\314\012\013\122\326\314\276\366\256\361\352"
  "\161\003\176\321\013\076\275\177\070\332\207\152\067\243\074\142"
  "\160\207\126\074\030\066\334\046\155\315\333\170\237\026\231\307"
  "\256\251\300\224\150\336\144\143\155\177\357\114\353\121\340\050"
  "\357\160\362\256\255\263\055\313\374\305\244\070\347\057\131\175"
  "\321\046\227\155\165\341\266\227\156\255\032\355\320\073\215\240"
  "\033\305\257\171\101\133\265\276\045\226\135\340\331\260\251\142"
  "\173\244\352\047\037\262\053\302\060\312\125\172\346\363\001\351"
  "\134\314\151\035\177\332\305\242\126\161\251\170\373\223\327\163"
  "\304\145\177\005\275\211\245\140\014\222\102\373\365\251\065\325"
  "\227\104\252\162\356\061\127\217\062\223\366\141\306\313\001\235"
  "\200\017\055\225\022\004\140\123\214\121\136\213\304\111\254\335"
  "\170\377\105\141\231\011\251\303\123\333\072\100\273\053\337\120"
  "\357\236\025\316\217\052\155\302\210\355\352\132\327\021\061\252"
  "\316\135\276\106\241\062\170\163\125\227\373\316\340\354\022\122"
  "\027\255\115\355\001\221\051\036\320\372\031\330\076\236\017\351"
  "\102\075\041\305\262\147\373\203\305\316\361\201\104\042\134\023"
  "\155\327\264\252\045\232\272\362\032\076\255\056\241\263\104\334"
  "\115\315\312\006\347\003\332\352\251\013\072\032\234\117\023\304"
  "\174\375\145\127\061\154\360\230\061\354\024\154\247\041\153\025"
  "\363\375\261\362\216\365\047\060\252\304\247\111\012\177\003\031"
  "\221\104\013\371\235\046\362\337\221\246\014\236\127\123\056\305"
  "\336\245\330\053\025\173\273\037\365\057\345\336\245\334\273\224"
  "\173\136\345\236\261\041\123\362\035\114\131\345\131\345\363\126"
  "\177\155\310\330\046\156\015\357\131\111\340\140\204\314\116\234"
  "\171\337\310\216\274\205\223\267\276\024\250\206\371\166\110\154"
  "\060\174\137\233\114\241\274\062\104\172\333\342\355\260\300\332"
  "\211\073\312\317\331\055\351\260\276\072\376\341\310\024\160\350"
  "\167\034\277\035\355\231\331\255\352\344\267\243\156\132\005\327"
  "\300\330\037\300\023\220\040\177\247\253\351\342\316\132\114\226"
  "\177\216\142\140\314\243\151\200\101\040\151\240\251\056\022\353"
  "\366\044\224\026\361\075\126\364\337\240\021\241\172\205\063\256"
  "\043\132\113\072\135\150\120\065\170\333\055\076\230\215\350\331"
  "\237\121\061\007\335\175\173\236\271\272\247\326\250\354\273\121"
  "\233\133\130\151\253\064\346\072\377\157\225\131\327\317\235\116"
  "\364\223\014\215\071\230\371\324\030\170\003\077\353\354\277\111"
  "\222\345\323\277\341\144\051\144\142\034\114\173\172\073\317\373"
  "\322\254\302\364\305\236\321\040\056\255\256\113\253\313\257\201"
  "\341\123\225\167\321\277\030\166\335\277\250\202\246\032\026\137"
  "\110\374\340\360\252\370\052\140\160\102\120\167\050\341\072\205"
  "\270\070\157\275\371\357\210\173\364\264\341\324\165\052\226\373"
  "\077\243\230\134\101\005\202\263\365\113\037\022\053\017\271\066"
  "\236\250\310\263\165\017\256\023\111\060\337\347\011\215\155\347"
  "\365\354\376\102\006\257\363\071\342\302\314\327\126\234\261\021"
  "\364\166\300\173\263\356\021\246\276\174\114\254\061\270\155\155"
  "\154\330\205\215\265\037\146\153\062\331\325\146\226\155\320\371"
  "\230\357\250\277\375\167\326\344\325\250\177\360\027\274\377\000"
  "\115\052\125\170\000\050\165\165\141\171\051\157\162\147\057\000"
  "\002\000\000\000\147\156\157\155\145\057\000\000\006\000\000\000"
  "\057\000\000\000\001\000\000\000\155\157\144\165\154\145\163\057"
  "\007\000\000\000\154\141\165\156\143\150\145\162\055\155\145\156"
  "\165\056\165\151\000\000\000\000\242\001\000\000\001\000\000\000"
  "\170\332\245\221\061\016\302\060\014\105\367\236\042\312\016\271"
  "\100\310\011\030\270\001\162\132\043\054\045\151\345\070\003\267"
  "\047\051\052\144\241\003\214\337\366\377\176\262\055\045\101\276"
  "\301\210\156\120\312\106\114\105\321\164\322\001\112\032\357\310"
  "\207\126\321\255\127\273\031\107\241\071\275\124\325\044\030\067"
  "\121\045\210\060\371\042\250\022\104\154\031\036\203\126\302\220"
  "\162\000\001\037\152\361\201\131\273\353\171\215\267\346\155\331"
  "\211\201\165\251\166\033\322\061\174\063\133\323\023\375\201\167"
  "\341\171\101\026\302\374\043\342\262\027\320\143\132\323\035\325"
  "\232\166\155\067\324\201\317\127\236\127\071\204\354\000\050\165"
  "\165\141\171\051\147\156\157\155\145\055\160\141\156\145\154\057"
  "\004\000\000\000\154\141\165\156\143\150\145\162\057\000\000\000"
  "\010\000\000\000\000\000\000\000\005\000\000\000\143\165\163\164"
  "\157\155\055\154\141\165\156\143\150\145\162\055\155\145\156\165"
  "\056\165\151\000\000\000\000\000\267\001\000\000\001\000\000\000"
  "\170\332\245\221\075\016\302\060\014\205\367\236\042\362\136\162"
  "\201\064\047\140\340\006\310\115\215\210\224\237\052\161\006\156"
  "\117\122\004\104\110\164\351\370\354\347\347\117\266\262\201\051"
  "\335\320\220\036\204\120\236\102\021\166\231\300\224\314\321\217"
  "\016\113\060\167\112\143\153\100\263\124\123\046\303\066\206\227"
  "\252\332\062\371\267\250\022\231\223\235\013\223\010\350\151\002"
  "\207\063\071\020\234\060\144\207\214\263\253\305\007\145\320\327"
  "\363\026\257\344\147\144\047\006\267\245\240\177\310\116\356\137"
  "\206\222\075\330\001\312\113\212\053\045\266\224\217\221\256\173"
  "\071\075\255\222\335\211\225\154\267\327\103\065\174\137\365\004"
  "\056\116\215\104\000\050\165\165\141\171\051" };
#endif /* !_MSC_VER */

static GStaticResource static_resource = { launcher_resource_data.data, sizeof (launcher_resource_data.data) - 1 /* nul terminator */, NULL, NULL, NULL };

G_MODULE_EXPORT
GResource *launcher_get_resource (void);
GResource *launcher_get_resource (void)
{
  return g_static_resource_get_resource (&static_resource);
}
/*
  If G_HAS_CONSTRUCTORS is true then the compiler support *both* constructors and
  destructors, in a usable way, including e.g. on library unload. If not you're on
  your own.

  Some compilers need #pragma to handle this, which does not work with macros,
  so the way you need to use this is (for constructors):

  #ifdef G_DEFINE_CONSTRUCTOR_NEEDS_PRAGMA
  #pragma G_DEFINE_CONSTRUCTOR_PRAGMA_ARGS(my_constructor)
  #endif
  G_DEFINE_CONSTRUCTOR(my_constructor)
  static void my_constructor(void) {
   ...
  }

*/

#ifndef __GTK_DOC_IGNORE__

#if  __GNUC__ > 2 || (__GNUC__ == 2 && __GNUC_MINOR__ >= 7)

#define G_HAS_CONSTRUCTORS 1

#define G_DEFINE_CONSTRUCTOR(_func) static void __attribute__((constructor)) _func (void);
#define G_DEFINE_DESTRUCTOR(_func) static void __attribute__((destructor)) _func (void);

#elif defined (_MSC_VER) && (_MSC_VER >= 1500)
/* Visual studio 2008 and later has _Pragma */

#include <stdlib.h>

#define G_HAS_CONSTRUCTORS 1

/* We do some weird things to avoid the constructors being optimized
 * away on VS2015 if WholeProgramOptimization is enabled. First we
 * make a reference to the array from the wrapper to make sure its
 * references. Then we use a pragma to make sure the wrapper function
 * symbol is always included at the link stage. Also, the symbols
 * need to be extern (but not dllexport), even though they are not
 * really used from another object file.
 */

/* We need to account for differences between the mangling of symbols
 * for x86 and x64/ARM/ARM64 programs, as symbols on x86 are prefixed
 * with an underscore but symbols on x64/ARM/ARM64 are not.
 */
#ifdef _M_IX86
#define G_MSVC_SYMBOL_PREFIX "_"
#else
#define G_MSVC_SYMBOL_PREFIX ""
#endif

#define G_DEFINE_CONSTRUCTOR(_func) G_MSVC_CTOR (_func, G_MSVC_SYMBOL_PREFIX)
#define G_DEFINE_DESTRUCTOR(_func) G_MSVC_DTOR (_func, G_MSVC_SYMBOL_PREFIX)

#define G_MSVC_CTOR(_func,_sym_prefix) \
  static void _func(void); \
  extern int (* _array ## _func)(void);              \
  int _func ## _wrapper(void) { _func(); g_slist_find (NULL,  _array ## _func); return 0; } \
  __pragma(comment(linker,"/include:" _sym_prefix # _func "_wrapper")) \
  __pragma(section(".CRT$XCU",read)) \
  __declspec(allocate(".CRT$XCU")) int (* _array ## _func)(void) = _func ## _wrapper;

#define G_MSVC_DTOR(_func,_sym_prefix) \
  static void _func(void); \
  extern int (* _array ## _func)(void);              \
  int _func ## _constructor(void) { atexit (_func); g_slist_find (NULL,  _array ## _func); return 0; } \
   __pragma(comment(linker,"/include:" _sym_prefix # _func "_constructor")) \
  __pragma(section(".CRT$XCU",read)) \
  __declspec(allocate(".CRT$XCU")) int (* _array ## _func)(void) = _func ## _constructor;

#elif defined (_MSC_VER)

#define G_HAS_CONSTRUCTORS 1

/* Pre Visual studio 2008 must use #pragma section */
#define G_DEFINE_CONSTRUCTOR_NEEDS_PRAGMA 1
#define G_DEFINE_DESTRUCTOR_NEEDS_PRAGMA 1

#define G_DEFINE_CONSTRUCTOR_PRAGMA_ARGS(_func) \
  section(".CRT$XCU",read)
#define G_DEFINE_CONSTRUCTOR(_func) \
  static void _func(void); \
  static int _func ## _wrapper(void) { _func(); return 0; } \
  __declspec(allocate(".CRT$XCU")) static int (*p)(void) = _func ## _wrapper;

#define G_DEFINE_DESTRUCTOR_PRAGMA_ARGS(_func) \
  section(".CRT$XCU",read)
#define G_DEFINE_DESTRUCTOR(_func) \
  static void _func(void); \
  static int _func ## _constructor(void) { atexit (_func); return 0; } \
  __declspec(allocate(".CRT$XCU")) static int (* _array ## _func)(void) = _func ## _constructor;

#elif defined(__SUNPRO_C)

/* This is not tested, but i believe it should work, based on:
 * http://opensource.apple.com/source/OpenSSL098/OpenSSL098-35/src/fips/fips_premain.c
 */

#define G_HAS_CONSTRUCTORS 1

#define G_DEFINE_CONSTRUCTOR_NEEDS_PRAGMA 1
#define G_DEFINE_DESTRUCTOR_NEEDS_PRAGMA 1

#define G_DEFINE_CONSTRUCTOR_PRAGMA_ARGS(_func) \
  init(_func)
#define G_DEFINE_CONSTRUCTOR(_func) \
  static void _func(void);

#define G_DEFINE_DESTRUCTOR_PRAGMA_ARGS(_func) \
  fini(_func)
#define G_DEFINE_DESTRUCTOR(_func) \
  static void _func(void);

#else

/* constructors not supported for this compiler */

#endif

#endif /* __GTK_DOC_IGNORE__ */

#ifdef G_HAS_CONSTRUCTORS

#ifdef G_DEFINE_CONSTRUCTOR_NEEDS_PRAGMA
#pragma G_DEFINE_CONSTRUCTOR_PRAGMA_ARGS(launcherresource_constructor)
#endif
G_DEFINE_CONSTRUCTOR(launcherresource_constructor)
#ifdef G_DEFINE_DESTRUCTOR_NEEDS_PRAGMA
#pragma G_DEFINE_DESTRUCTOR_PRAGMA_ARGS(launcherresource_destructor)
#endif
G_DEFINE_DESTRUCTOR(launcherresource_destructor)

#else
#warning "Constructor not supported on this compiler, linking in resources will not work"
#endif

static void launcherresource_constructor (void)
{
  g_static_resource_init (&static_resource);
}

static void launcherresource_destructor (void)
{
  g_static_resource_fini (&static_resource);
}
